Index: /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/src/OCE/DYN/dynatf.F90
===================================================================
--- /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/src/OCE/DYN/dynatf.F90	(revision 13892)
+++ /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/src/OCE/DYN/dynatf.F90	(revision 13893)
@@ -332,6 +332,7 @@
             CALL iom_put(  "utau", zutau(:,:) )
             DEALLOCATE(zutau)
-         ELSE
-            CALL iom_put(  "utau", utau(:,:) )
+         !ELSE
+         ! #laurent: it is done in blk_oce_1() of sbcblk.F90 !
+         !       CALL iom_put(  "utau", utau(:,:) )
          ENDIF
       ENDIF
@@ -346,6 +347,7 @@
             CALL iom_put(  "vtau", zvtau(:,:) )
             DEALLOCATE(zvtau)
-         ELSE
-            CALL iom_put(  "vtau", vtau(:,:) )
+         !ELSE
+         ! #laurent: it is done in blk_oce_1() of sbcblk.F90 !
+         !   CALL iom_put(  "vtau", vtau(:,:) )
          ENDIF
       ENDIF
Index: /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/src/OCE/SBC/sbcblk.F90
===================================================================
--- /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/src/OCE/SBC/sbcblk.F90	(revision 13892)
+++ /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/src/OCE/SBC/sbcblk.F90	(revision 13893)
@@ -64,5 +64,5 @@
 
    USE sbc_phy        ! Catalog of functions for physical/meteorological parameters in the marine boundary layer
-
+   USE zdfdrg  , ONLY : ln_drgice_imp  ! to know if we should iom_put wind stress vector (utau,vtau) #laurent
 
    IMPLICIT NONE
@@ -857,5 +857,10 @@
 
          CALL iom_put( "taum_oce", taum*tmask(:,:,1) )   ! output wind stress module
-
+         IF ( .NOT. (ln_drgice_imp.OR.ln_isfcav) ) THEN
+            ! #Laurent: because otherwize utau and vtau are saved into dyn_atf() of dynatf.F90
+            CALL iom_put( "utau", utau(:,:) )
+            CALL iom_put( "vtau", vtau(:,:) )
+         END IF
+         
          IF(sn_cfctl%l_prtctl) THEN
             CALL prt_ctl( tab2d_1=pssq   , clinfo1=' blk_oce_1: pssq   : ')
Index: /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce+ice/namelist_ecmwf-an05_cfg
===================================================================
--- /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce+ice/namelist_ecmwf-an05_cfg	(revision 13892)
+++ /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce+ice/namelist_ecmwf-an05_cfg	(revision 13893)
@@ -21,5 +21,5 @@
 !-----------------------------------------------------------------------
    rn_dept1    =  1.0   ! depth (m) at which the prescribed SST is taken  == depth of first T point! (IMPORTANT for warm-layer impact, the deeper, the more pronounced!)
-   !                    ! [PAPA station = 1 m]
+   !                    ! [ERA5_NorthGreenland station = 1 m]
 /
 !-----------------------------------------------------------------------
@@ -47,8 +47,8 @@
 /
 !-----------------------------------------------------------------------
-&namc1d        !   1D configuration options / STATION_ASF               ("key_c1d" default: PAPA station)
-!-----------------------------------------------------------------------
-   rn_lat1d    =      50.1 !  Column latitude    [PAPA station]
-   rn_lon1d    =    215.1  !  Column longitude   [PAPA station]
+&namc1d        !   1D configuration options / STATION_ASF
+!-----------------------------------------------------------------------
+   rn_lat1d    =   84. !  Column latitude    [ERA5_NorthGreenland station]
+   rn_lon1d    =  324. !  Column longitude   [ERA5_NorthGreenland station]
 /
 !-----------------------------------------------------------------------
Index: /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce+ice/namelist_ecmwf-cstc_cfg
===================================================================
--- /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce+ice/namelist_ecmwf-cstc_cfg	(revision 13892)
+++ /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce+ice/namelist_ecmwf-cstc_cfg	(revision 13893)
@@ -21,5 +21,5 @@
 !-----------------------------------------------------------------------
    rn_dept1    =  1.0   ! depth (m) at which the prescribed SST is taken  == depth of first T point! (IMPORTANT for warm-layer impact, the deeper, the more pronounced!)
-   !                    ! [PAPA station = 1 m]
+   !                    ! [ERA5_NorthGreenland station = 1 m]
 /
 !-----------------------------------------------------------------------
@@ -47,8 +47,8 @@
 /
 !-----------------------------------------------------------------------
-&namc1d        !   1D configuration options / STATION_ASF               ("key_c1d" default: PAPA station)
-!-----------------------------------------------------------------------
-   rn_lat1d    =      50.1 !  Column latitude    [PAPA station]
-   rn_lon1d    =    215.1  !  Column longitude   [PAPA station]
+&namc1d        !   1D configuration options / STATION_ASF
+!-----------------------------------------------------------------------
+   rn_lat1d    =   84. !  Column latitude    [ERA5_NorthGreenland station]
+   rn_lon1d    =  324. !  Column longitude   [ERA5_NorthGreenland station]
 /
 !-----------------------------------------------------------------------
Index: /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce+ice/namelist_ecmwf-lg15_cfg
===================================================================
--- /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce+ice/namelist_ecmwf-lg15_cfg	(revision 13892)
+++ /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce+ice/namelist_ecmwf-lg15_cfg	(revision 13893)
@@ -21,5 +21,5 @@
 !-----------------------------------------------------------------------
    rn_dept1    =  1.0   ! depth (m) at which the prescribed SST is taken  == depth of first T point! (IMPORTANT for warm-layer impact, the deeper, the more pronounced!)
-   !                    ! [PAPA station = 1 m]
+   !                    ! [ERA5_NorthGreenland station = 1 m]
 /
 !-----------------------------------------------------------------------
@@ -47,8 +47,8 @@
 /
 !-----------------------------------------------------------------------
-&namc1d        !   1D configuration options / STATION_ASF               ("key_c1d" default: PAPA station)
-!-----------------------------------------------------------------------
-   rn_lat1d    =      50.1 !  Column latitude    [PAPA station]
-   rn_lon1d    =    215.1  !  Column longitude   [PAPA station]
+&namc1d        !   1D configuration options / STATION_ASF
+!-----------------------------------------------------------------------
+   rn_lat1d    =   84. !  Column latitude    [ERA5_NorthGreenland station]
+   rn_lon1d    =  324. !  Column longitude   [ERA5_NorthGreenland station]
 /
 !-----------------------------------------------------------------------
Index: /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce+ice/namelist_ecmwf-lu12_cfg
===================================================================
--- /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce+ice/namelist_ecmwf-lu12_cfg	(revision 13892)
+++ /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce+ice/namelist_ecmwf-lu12_cfg	(revision 13893)
@@ -21,5 +21,5 @@
 !-----------------------------------------------------------------------
    rn_dept1    =  1.0   ! depth (m) at which the prescribed SST is taken  == depth of first T point! (IMPORTANT for warm-layer impact, the deeper, the more pronounced!)
-   !                    ! [PAPA station = 1 m]
+   !                    ! [ERA5_NorthGreenland station = 1 m]
 /
 !-----------------------------------------------------------------------
@@ -47,8 +47,8 @@
 /
 !-----------------------------------------------------------------------
-&namc1d        !   1D configuration options / STATION_ASF               ("key_c1d" default: PAPA station)
-!-----------------------------------------------------------------------
-   rn_lat1d    =      50.1 !  Column latitude    [PAPA station]
-   rn_lon1d    =    215.1  !  Column longitude   [PAPA station]
+&namc1d        !   1D configuration options / STATION_ASF
+!-----------------------------------------------------------------------
+   rn_lat1d    =   84. !  Column latitude    [ERA5_NorthGreenland station]
+   rn_lon1d    =  324. !  Column longitude   [ERA5_NorthGreenland station]
 /
 !-----------------------------------------------------------------------
Index: /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce/namelist_andreas_cfg
===================================================================
--- /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce/namelist_andreas_cfg	(revision 13892)
+++ /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce/namelist_andreas_cfg	(revision 13893)
@@ -21,5 +21,5 @@
 !-----------------------------------------------------------------------
    rn_dept1    =  1.0   ! depth (m) at which the prescribed SST is taken  == depth of first T point! (IMPORTANT for warm-layer impact, the deeper, the more pronounced!)
-   !                    ! [PAPA station = 1 m]
+   !                    ! [ERA5_NorthGreenland station = 1 m]
 /
 !-----------------------------------------------------------------------
@@ -47,8 +47,8 @@
 /
 !-----------------------------------------------------------------------
-&namc1d        !   1D configuration options / STATION_ASF               ("key_c1d" default: PAPA station)
-!-----------------------------------------------------------------------
-   rn_lat1d    =      50.1 !  Column latitude    [PAPA station]
-   rn_lon1d    =    215.1  !  Column longitude   [PAPA station]
+&namc1d        !   1D configuration options / STATION_ASF
+!-----------------------------------------------------------------------
+   rn_lat1d    =   84. !  Column latitude    [ERA5_NorthGreenland station]
+   rn_lon1d    =  324. !  Column longitude   [ERA5_NorthGreenland station]
 /
 !-----------------------------------------------------------------------
Index: /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce/namelist_coare3p6_cfg
===================================================================
--- /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce/namelist_coare3p6_cfg	(revision 13892)
+++ /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce/namelist_coare3p6_cfg	(revision 13893)
@@ -21,5 +21,5 @@
 !-----------------------------------------------------------------------
    rn_dept1    =  1.0   ! depth (m) at which the prescribed SST is taken  == depth of first T point! (IMPORTANT for warm-layer impact, the deeper, the more pronounced!)
-   !                    ! [PAPA station = 1 m]
+   !                    ! [ERA5_NorthGreenland station = 1 m]
 /
 !-----------------------------------------------------------------------
@@ -47,8 +47,8 @@
 /
 !-----------------------------------------------------------------------
-&namc1d        !   1D configuration options / STATION_ASF               ("key_c1d" default: PAPA station)
-!-----------------------------------------------------------------------
-   rn_lat1d    =      50.1 !  Column latitude    [PAPA station]
-   rn_lon1d    =    215.1  !  Column longitude   [PAPA station]
+&namc1d        !   1D configuration options / STATION_ASF
+!-----------------------------------------------------------------------
+   rn_lat1d    =   84. !  Column latitude    [ERA5_NorthGreenland station]
+   rn_lon1d    =  324. !  Column longitude   [ERA5_NorthGreenland station]
 /
 !-----------------------------------------------------------------------
Index: /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce/namelist_ecmwf_cfg
===================================================================
--- /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce/namelist_ecmwf_cfg	(revision 13892)
+++ /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce/namelist_ecmwf_cfg	(revision 13893)
@@ -21,5 +21,5 @@
 !-----------------------------------------------------------------------
    rn_dept1    =  1.0   ! depth (m) at which the prescribed SST is taken  == depth of first T point! (IMPORTANT for warm-layer impact, the deeper, the more pronounced!)
-   !                    ! [PAPA station = 1 m]
+   !                    ! [ERA5_NorthGreenland station = 1 m]
 /
 !-----------------------------------------------------------------------
@@ -47,8 +47,8 @@
 /
 !-----------------------------------------------------------------------
-&namc1d        !   1D configuration options / STATION_ASF               ("key_c1d" default: PAPA station)
-!-----------------------------------------------------------------------
-   rn_lat1d    =      50.1 !  Column latitude    [PAPA station]
-   rn_lon1d    =    215.1  !  Column longitude   [PAPA station]
+&namc1d        !   1D configuration options / STATION_ASF
+!-----------------------------------------------------------------------
+   rn_lat1d    =   84. !  Column latitude    [ERA5_NorthGreenland station]
+   rn_lon1d    =  324. !  Column longitude   [ERA5_NorthGreenland station]
 /
 !-----------------------------------------------------------------------
Index: /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce/namelist_ncar_cfg
===================================================================
--- /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce/namelist_ncar_cfg	(revision 13892)
+++ /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/ERA5/oce/namelist_ncar_cfg	(revision 13893)
@@ -21,5 +21,5 @@
 !-----------------------------------------------------------------------
    rn_dept1    =  1.0   ! depth (m) at which the prescribed SST is taken  == depth of first T point! (IMPORTANT for warm-layer impact, the deeper, the more pronounced!)
-   !                    ! [PAPA station = 1 m]
+   !                    ! [ERA5_NorthGreenland station = 1 m]
 /
 !-----------------------------------------------------------------------
@@ -47,8 +47,8 @@
 /
 !-----------------------------------------------------------------------
-&namc1d        !   1D configuration options / STATION_ASF               ("key_c1d" default: PAPA station)
-!-----------------------------------------------------------------------
-   rn_lat1d    =      50.1 !  Column latitude    [PAPA station]
-   rn_lon1d    =    215.1  !  Column longitude   [PAPA station]
+&namc1d        !   1D configuration options / STATION_ASF
+!-----------------------------------------------------------------------
+   rn_lat1d    =   84. !  Column latitude    [ERA5_NorthGreenland station]
+   rn_lon1d    =  324. !  Column longitude   [ERA5_NorthGreenland station]
 /
 !-----------------------------------------------------------------------
Index: /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/launch_sasf.sh
===================================================================
--- /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/launch_sasf.sh	(revision 13892)
+++ /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/launch_sasf.sh	(revision 13893)
@@ -18,8 +18,7 @@
 #     => i_sea_ice: whether to compute fluxes over sea-ice as well
 #     => SFORC: string sufficient to copy relevant files as in "*${SFORC}*.nc"
-#FORCING="PAPA"         ; i_sea_ice=0 ; SFORC="Station_PAPA_50N-145W"
-#FORCING="ERA5_arctic" ; i_sea_ice=1 ; SFORC="ERA5_arctic_surface_81N_36p75E_1h" ; # "ERA5_arctic" WITH ice/air flux computation
+#FORCING="PAPA"                 ; i_sea_ice=0 ; SFORC="Station_PAPA_50N-145W"
 FORCING="ERA5_NorthGreenland" ; i_sea_ice=1 ; SFORC="ERA5_NorthGreenland_surface_84N_-36E_1h" ; # WITH ice/air flux computation
-#FORCING="ERA5_arctic" ; i_sea_ice=0 ; SFORC="ERA5_arctic_surface_81N_36p75E_1h" ; # "ERA5_arctic" WITHOUT ice/air flux computation
+#FORCING="ERA5_NorthGreenland" ; i_sea_ice=0 ; SFORC="ERA5_NorthGreenland_surface_84N_-36E_1h" ; # "ERA5_arctic" WITHOUT ice/air flux computation
 
 
Index: /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/plot_station_asf_ICE.py
===================================================================
--- /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/plot_station_asf_ICE.py	(revision 13892)
+++ /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/plot_station_asf_ICE.py	(revision 13893)
@@ -195,5 +195,5 @@
         #
         id_in = Dataset(cf_in[ja])
-        xF[:,ja] = id_in.variables[L_VNEM[jv]][:,1,1]  ; # only the center point of the 3x3 spatial domain!        
+        xF[:,ja] = id_in.variables[L_VNEM[jv]][:,1,1]  ; # only the center point of the 3x3 spatial domain!
         if ja == 0: cvar_lnm = id_in.variables[L_VNEM[jv]].long_name
         id_in.close()
@@ -258,5 +258,5 @@
             #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
             fig = plt.figure(num = 10+jv, figsize=size_fig, facecolor='w', edgecolor='k')
-            ax1 = plt.axes([0.083, 0.23, 0.9, 0.7])
+            ax1 = plt.axes([0.09, 0.23, 0.9, 0.7])
             ax1.set_xticks(vtime[::xticks_d])
             ax1.xaxis.set_major_formatter(mdates.DateFormatter('%Y-%m-%d %H:%M:%S'))
@@ -266,5 +266,5 @@
                 fplot = nmp.ma.masked_where( xF[:,ja]==0., xF[:,ja] )
                 plt.plot(vtime, fplot, '-', color=l_color[ja], \
-                         linewidth=l_width[ja], label=list_exp[ja], zorder=10+ja)
+                         linewidth=l_width[ja], label=list_exp[ja], alpha=0.6) #, zorder=10+ja)
 
             ax1.set_ylim(-yrng,yrng) ; ax1.set_xlim(vtime[0],vtime[Nt-1])
Index: MO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/MY_SRC/README.md
===================================================================
--- /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/MY_SRC/README.md	(revision 13892)
+++ 	(revision )
@@ -1,13 +1,0 @@
-## Welcome to ```STATION_ASF```, a NEMO setup which mimics an off-shore station dedicated to the measure of Air-Sea Fluxes (ASF).
-
-
-
-### Important namelist parameters
-
-* ```rn_dept1@namusr_def:``` depth (m) at which the prescribed SST is taken (i.e. depth of first T-point); important due to impact on warm-layer estimate, the deeper, the more pronounced!
-
-* ```rn_lat1d,rn_lon1d@namc1d:``` fixed coordinates of the location of the station (buoy, platform, etc).
-
-* ```namsbc_blk:``` to be filled carefully, just as for "C1D", the prescribed surface ATMOSPHERIC state (files) are time series of shape 3x3 in space
-
-* ```namsbc_sas:``` to be filled carefully, just as for "C1D", the prescribed surface OCEAN state (files) are time series of shape 3x3 in space
Index: /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/README.md
===================================================================
--- /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/README.md	(revision 13892)
+++ /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/README.md	(revision 13893)
@@ -5,20 +5,13 @@
 Author: Laurent Brodeau, 2020
 
-NOTE: if working with the trunk of NEMO, you are strongly advised to use the same test-case but on the `NEMO-examples` GitHub depo:
-https://github.com/NEMO-ocean/NEMO-examples/tree/master/STATION_ASF
--->
-
-
-
 ## Objectives
 
-```STATION_ASF``` is a demonstration test-case that mimics a (static) in-situ station (buoy, platform) dedicated to the estimation of surface air-sea fluxes by means of *widely-measured* (bulk) meteorological surface parameters.
-
-```STATION_ASF``` has been constructed by merging the *single column* and the *standalone surface module* configurations of NEMO. In short, it can be defined as "SAS meets C1D". As such, the spatial domain of ```STATION_ASF``` is punctual (1D, well actually 3 x 3 as in C1D).
-
-```STATION_ASF``` is therefore a versatile tool, and extremely lightweight in terms of computing requirements, to test the different bulk algorithms and cool-skin/warm-layer parameterization options included in NEMO.
-
-As input ```STATION_ASF``` will require the traditional *bulk* sea surface parameters:
-
+`STATION_ASF` is a demonstration test-case that mimics a (static) in-situ station (buoy, platform) dedicated to the estimation of surface air-sea fluxes by means of *widely-measured* (bulk) meteorological surface parameters.
+
+`STATION_ASF` has been constructed by merging the *single column* and the *standalone surface module* configurations of NEMO. In short, it can be defined as "SAS meets C1D". As such, the spatial domain of `STATION_ASF` is punctual (1D, well actually 3 x 3 as in C1D).
+
+`STATION_ASF` is therefore a versatile tool, and extremely lightweight in terms of computing requirements, to test the different bulk algorithms and cool-skin/warm-layer parameterization options included in NEMO.
+
+As input `STATION_ASF` will require the traditional *bulk* sea surface parameters:
 - Bulk sea surface temperature (SST) at _z<sub>SST</sub>_ meters below the surface
 - Surface current vector
@@ -26,5 +19,4 @@
 
 as well as the usual surface atmospheric state:
-
 - air temperature at _z<sub>t</sub>_ meters above the surface
 - air humidity  at _z<sub>t</sub>_ meters above the surface (specific humidity or relative humidity or dew-point temperature)
@@ -34,5 +26,6 @@
 - Downwelling longwave radiation
 
-### Example of diagnostics from `STATION_ASF`
+
+### Example of diagnostics with `STATION_ASF`
 
 (Generated with script `./EXPREF/plot_station_asf_simple.py`)
@@ -49,5 +42,5 @@
 ## Physical description
 
-### Important namelist parameters specific to STATION_ASF
+### Important namelist parameters specific to `STATION_ASF`
 
 * ```rn_dept1@namusr_def:``` depth (m) at which the prescribed SST is taken (*i.e.* depth of first T-point); important due to impact on warm-layer estimate, the deeper, the more pronounced!
@@ -58,26 +51,4 @@
 
 * ```namsbc_sas:``` to be filled carefully, just as for "C1D", the prescribed surface OCEAN state (files) are time series of shape 3x3 in space
-
-
-
-## Input files to test STATION ASF
-
-One full year (2018) of processed hourly data from the PAPA station (buoy) is found into the `input_data` directory.
-These three files are everything you need to play with the set of *namelists* provided for this test-case.
-
-- ```Station_PAPA_50N-145W_atm_hourly_y2018.nc```  → contains hourly surface atmospheric state
-- ```Station_PAPA_50N-145W_precip_daily_y2018.nc``` → contains daily precipitation
-- ```Station_PAPA_50N-145W_oce_hourly_y2018.nc``` → contains hourly sea surface state
-
-For station PAPA (50.1 N, 144.9 W), air temperature and humidity are measured at 2.5 m, the wind speed at 4 m, and the SST at 1 m below the surface, hence the following namelist parameters are given:
-
-- `&namusr_def`
-  - ```rn_dept1 =    1.  ```
-- `&namc1d`
-  - ```rn_lat1d =  50.1 ```
-  - ```rn_lon1d = 215.1```
-- `&namsbc_blk`
-  - ```rn_zqt   =   2.5```
-  - ```rn_zu    =    4.```
 
 
@@ -157,30 +128,132 @@
 
 
-## Playing with STATION_ASF
+## Playing with `STATION_ASF`
+
+
+### Input forcing files to test STATION ASF
+
+By default, `STATION_ASF` comes with two forcing sets:
+
+* The `PAPA` forcing is an "open-ocean-only" hourly forcing, that corresponds to a real off-shore platform, the PAPA station (North-East Pacific, 50°N, 145°W). Hence the data provided for the PAPA test is actual data measured by the PAPA station.
+
+* The `ERA5_NorthGreenland` forcing simulates a *virtual station* as it is extracted from the ECMWF ERA5 reanalysis right north of Greenland (84°N,36°W). This forcing is also hourly and allows for `STATION_ASF` to be used with sea-ice support as this particular location is ice-covered year-round.
+
+
+#### `PAPA` forcing
+
+One full year (2018) of processed hourly data from the PAPA station (buoy) are found in the 3 following files (found in `tests/STATION_ASF/input_data`):
+- ```Station_PAPA_50N-145W_atm_hourly_y2018.nc```  → contains hourly surface atmospheric state
+- ```Station_PAPA_50N-145W_precip_daily_y2018.nc``` → contains daily precipitation
+- ```Station_PAPA_50N-145W_oce_hourly_y2018.nc``` → contains hourly sea surface state
+
+For station PAPA (50.1 N, 144.9 W), air temperature and humidity are measured at 2.5 m, the wind speed at 4 m, and the SST at 1 m below the surface, hence the following namelist parameters are given:
+
+    ...
+    &namusr_def
+        rn_dept1 =    1. 
+    ...
+    &namc1d
+        rn_lat1d =  50.1 
+        rn_lon1d = 215.1
+    ...
+    &namsbc_blk
+        ...
+        rn_zqt = 2.5
+        rn_zu  = 4.
+        ...
+        ln_humi_rlh = .true.  !  humidity in PAPA data is relative humidity  [%]
+        ...
+
+The namelists for the `PAPA` forcing are located into `EXPREF/PAPA/oce/`
+
+
+
+#### `ERA5_NorthGreenland` forcing
+
+The entire forcing is found in one single file: `ERA5_NorthGreenland_surface_84N_-36E_1h_y2018.nc`.
+Since we are dealing with a reanalysis of the ECMWF:
+
+    ...
+    &namusr_def
+        rn_dept1 = 1. ! we assume ECMWF uses a prescribed bulk SST product at the standard depth of 1m...
+    ...
+    &namc1d
+        rn_lat1d =  84. 
+        rn_lon1d = 324.
+    ...
+    &namsbc_blk
+        ...
+        rn_zqt =  2.
+        rn_zu  = 10.
+        ...
+        ln_humi_dpt = .true.  !  humidity in ERA5 is dew-point temperature [K]
+        ...
+
+The namelists for the `ERA5_NorthGreenland` forcing are located into `ERA5/oce+ice/` or `ERA5/oce`, depending whether you want to use sea-ice support or not.
+
+
+
+### Compiling and launching STATION_ASF simulations
 
 First compile the test-case as follows (compile with xios-2.5 support → check your ARCH file):
 
-```./makenemo -a STATION_ASF -m <your_arch> -n STATION_ASF2 -j 4```
-
-Move to: ```tests/STATION_ASF/EXPREF/```
-Then you can use the script ``launch_sasf.sh`` found in  ```EXPREF/``` to launch 3 simulations (one for each bulk parameterization available). You need to adapt the following variable to your environment in the script:
-
-- ```NEMO_ROOT_DIR``` : NEMO root directory where to fetch compiled STATION_ASF ```nemo.exe``` + setup (such as ```${NEMO_ROOT_DIR}/tests/STATION_ASF```)
-
-- ```PROD_DIR``` :  Directory where to run the simulation
-
-- ```DATA_IN_DIR``` : Directory containing sea-surface + atmospheric forcings (```tests/STATION_ASF/input_data/```)
-
-If everything goes according to plan, ``launch_sasf.sh`` should have generated the 3 following sets of output files into `${PROD_DIR}/output`:
-
-    STATION_ASF-COARE3p6_1h_20180101_20181231_gridT.nc
-    STATION_ASF-COARE3p6_1h_20180101_20181231_gridU.nc
-    STATION_ASF-COARE3p6_1h_20180101_20181231_gridV.nc
-    STATION_ASF-ECMWF_1h_20180101_20181231_gridT.nc
-    STATION_ASF-ECMWF_1h_20180101_20181231_gridU.nc
-    STATION_ASF-ECMWF_1h_20180101_20181231_gridV.nc
-    STATION_ASF-NCAR_1h_20180101_20181231_gridT.nc
-    STATION_ASF-NCAR_1h_20180101_20181231_gridU.nc
-    STATION_ASF-NCAR_1h_20180101_20181231_gridV.nc
+    $ ./makenemo -a STATION_ASF -m <your_arch> -n STATION_ASF2 -j 4
+
+Move to `tests/STATION_ASF/EXPREF/`, there, you can use the script ``launch_sasf.sh`` to launch `STATION_ASF` simulations. You need to adapt the following variable to your environment in the script:
+
+- ```CONFIG_BLD``` : the name of the sub-directory of `tests/` in which `STATION_ASF` has been compiled (default: `CONFIG_BLD="STATION_ASF2"`)
+
+- ```FORCING``` : this is where you pick the forcing you want to use, and wether to use sea-ice support or not (only available for `ERA5_NorthGreenland` forcing)
+
+- ```PROD_DIR``` :  Directory in which the simulation will be installed and run
+
+- ```MPI_LAUNCH```: this is where you can adapt how the `nemo.exe` executable is launched on your system (default: `MPI_LAUNCH="mpirun -n 1"`)
+
+
+Now, it's time to launch simulations: 
+
+    $ ./launch_sasf.sh
+
+If everything goes according to plan, ``launch_sasf.sh`` should have generated the 4 following sets of output files into `${PROD_DIR}/output` (example for PAPA forcing, 4 algos tested):
+
+    STATION_ASF-ANDREAS_PAPA_1h_20180101_20181231_gridT.nc
+    STATION_ASF-ANDREAS_PAPA_1h_20180101_20181231_gridU.nc
+    STATION_ASF-ANDREAS_PAPA_1h_20180101_20181231_gridV.nc
+    STATION_ASF-COARE3p6_PAPA_1h_20180101_20181231_gridT.nc
+    STATION_ASF-COARE3p6_PAPA_1h_20180101_20181231_gridU.nc
+    STATION_ASF-COARE3p6_PAPA_1h_20180101_20181231_gridV.nc
+    STATION_ASF-ECMWF_PAPA_1h_20180101_20181231_gridT.nc
+    STATION_ASF-ECMWF_PAPA_1h_20180101_20181231_gridU.nc
+    STATION_ASF-ECMWF_PAPA_1h_20180101_20181231_gridV.nc
+    STATION_ASF-NCAR_PAPA_1h_20180101_20181231_gridT.nc
+    STATION_ASF-NCAR_PAPA_1h_20180101_20181231_gridU.nc
+    STATION_ASF-NCAR_PAPA_1h_20180101_20181231_gridV.nc
+
+
+#### Post-processing and figures
+
+Use the `plot_station_asf_OCE.py` script (Python 3) to generate a multitude of figures that compares the *open ocean* transfer coefficients and fluxes between the 4 algorithms, in our case with the `PAPA` forcing:
+
+    $ ./plot_station_asf_OCE.py -d <PROD_DIR> -f PAPA
+
+Example of a comparison plot:
+![plot](https://github.com/NEMO-ocean/NEMO-examples/blob/master/STATION_ASF/figs/Cd_PAPA_open-ocean.svg)
+
+If you have used a forcing with sea-ice support, such as `ERA5_NorthGreenland`, you can do the same for *sea-ice* transfer coefficients and fluxes, which will compare *air-ice* bulk algorithms:
+
+    $ ./plot_station_asf_ICE.py -d <PROD_DIR> -f ERA5_NorthGreenland
+
+Example of a comparison plot:
+![plot](https://github.com/NEMO-ocean/NEMO-examples/blob/master/STATION_ASF/figs/Cd_ERA5_NorthGreenland_sea-ice.svg)
+Note: when sea-ice support is enabled, typically by using the following `FORCING` configuration in script `launch_sasf.sh`:
+
+    FORCING="ERA5_NorthGreenland" ; i_sea_ice=1 ; SFORC="ERA5_NorthGreenland_surface_84N_-36E_1h"
+    
+the fact that `i_sea_ice=1` trigers the computation of *air-ice* fluxes with different bulk *air-ice* algorithms, over the remaining open-ocean fraction the same *air-sea* algorithm is used: `ECMWF`.
+
+
+-----------------------
+
+#### TO FINISH, BROKEN !!!
 
 Then, you can fire the Jupyter notebook [`station_asf_notebook.ipynb`](https://github.com/NEMO-ocean/NEMO-examples/blob/master/STATION_ASF/notebook/station_asf_notebook.ipynb) found into the `notebook` directory! In which you should update `cprod_dir` to the same path as `PROD_DIR` of `launch_sasf.sh`...

Index: /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/plot_station_asf_OCE.py
===================================================================
--- /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/plot_station_asf_OCE.py	(revision 13892)
+++ /NEMO/branches/2020/dev_r13648_ASINTER-04_laurent_bulk_ice/tests/STATION_ASF/EXPREF/plot_station_asf_OCE.py	(revision 13893)
@@ -28,7 +28,14 @@
 rDPI=100.
 
-l_color = [ '0.85'    ,  '#ffed00' , '#008ab8' , '0.4'  ] ; # colors to differentiate algos on the plot
-l_width = [  4        ,     3      ,    2      ,  1     ] ; # line-width to differentiate algos on the plot
-l_style = [ '-'       ,    '-'     ,   '-'     , '--'   ] ; # line-style
+#l_color = [ '0.85'    ,  '#ffed00' , '#008ab8' , '0.4'  ] ; # colors to differentiate algos on the plot
+#l_width = [  4        ,     3      ,    2      ,  1     ] ; # line-width to differentiate algos on the plot
+#l_style = [ '-'       ,    '-'     ,   '-'     , '--'   ] ; # line-style
+
+#ffed00: yellow ON
+#E8A727: ornage
+
+l_color = [ '0.3' , '#E8A727', '0.1'  , '#008ab8'  ] ; # colors to differentiate algos on the plot
+l_width = [   2   ,    2     ,  1.5   ,    2       ] ; # line-width to differentiate algos on the plot
+l_style = [  '-'  ,    '-'   , '--'   ,   '-'      ] ; # line-style
 
 
@@ -43,4 +50,6 @@
 L_PREC = [      3      ,      3      ,      0      ,      0        ,       0      ,      0      ,     2       ,        3             ]
 L_ANOM = [   False     ,   False     ,   True      ,    True       ,    True      ,    True     ,   True      ,      False           ]
+L_MAXT = [  10000.   ,     10000.,  10000.   ,  10000.      ,  10000.    ,  10000.      , 10000.     ,      1.5    ]
+L_MINT = [    0.001  ,     0.001 , -10000.   , -10000.      , -10000.    , -10000.      ,-10000.     ,   -10000.   ]
 
 # About STATION_ASF output files to read:
@@ -220,7 +229,12 @@
         #
         id_in = Dataset(cf_in[ja])
-        xF[:,ja] = id_in.variables[L_VNEM[jv]][:,1,1] # only the center point of the 3x3 spatial domain!
+        xF[:,ja] = id_in.variables[L_VNEM[jv]][:,1,1]  ; # only the center point of the 3x3 spatial domain!
         if ja == 0: cvar_lnm = id_in.variables[L_VNEM[jv]].long_name
         id_in.close()
+        #
+        id_toolarge, = nmp.where( xF[:,ja] > L_MAXT[jv] ) # 
+        xF[id_toolarge,ja] = L_MAXT[jv]
+        id_toosmall, = nmp.where( xF[:,ja] < L_MINT[jv] ) ; print("id_toosmall =", id_toosmall)
+        xF[id_toosmall,ja] = L_MINT[jv]
 
     idx_okay = nmp.where( nmp.abs(xF) < 1.e+10 )
@@ -236,5 +250,5 @@
         fplot = nmp.ma.masked_where( xF[:,ja]==0., xF[:,ja] )
         plt.plot(vtime, fplot, '-', color=l_color[ja], \
-                 linestyle=l_style[ja], linewidth=l_width[ja], label=list_exp[ja], zorder=10+ja)
+                 linestyle=l_style[ja], linewidth=l_width[ja], label=list_exp[ja], alpha=0.6 ) #zorder=10+ja)
 
     fmin, fmax = round_bounds( nmp.min(xF[idx_okay]) , nmp.max(xF[idx_okay]), base=L_BASE[jv], prec=L_PREC[jv])
@@ -286,5 +300,5 @@
                 fplot = nmp.ma.masked_where( xF[:,ja]==0., xF[:,ja] )
                 plt.plot(vtime, fplot, '-', color=l_color[ja], \
-                         linewidth=l_width[ja], label=list_exp[ja], zorder=10+ja)
+                         linewidth=l_width[ja], label=list_exp[ja], alpha=0.6) #, zorder=10+ja)
 
             ax1.set_ylim(-yrng,yrng) ; ax1.set_xlim(vtime[0],vtime[Nt-1])